const { Perf } = require("rlib-perf");
const _ = require("lodash");
const R = require("rlib");;

function* iterableFilter(items, callback) {
    for (const item of items) {
        if (callback(item)) {
            yield item;
        }
    }
};

const p = new Perf();;

p.title = "Filter function comparison";
p.trials = 100;

// Setup each test with some data
p.setup( n => {
    return R.repeatFunc(1000 * (n + 1), idx => idx);
});

// Label each trial for CSV purposes
p.label(n => `${1000 * (n + 1)}`);;

// Common filter function
function filterFunc(n) {
    return n % 3 === 0;
}

p.test("native", state => {
    state.filter(filterFunc);
});

p.test("lodash", state => {
    _.filter(state, filterFunc);
});

p.test("rlib", state => {
    R.filter(state, filterFunc);
});

p.test("iterable", state => {
    const it = iterableFilter(state, filterFunc);
    [...it];
});;

p.run();;

p.print();;
